==> checkout-ui-react-0.2.0.tgz: package/src/icons/index.ts <==
export {default as camera} from './camera.svg';
export {default as cancelCircle} from './cancel-circle.svg';
export {default as caretDown} from './caret-down.svg';
export {default as cart} from './cart.svg';
export {default as checkmark} from './checkmark.svg';
export {default as checkmarkCircle} from './checkmark-circle.svg';
export {default as chevronDown} from './chevron-down.svg';
export {default as chevronUp} from './chevron-up.svg';
export {default as chevronRight} from './chevron-right.svg';
export {default as chevronLeft} from './chevron-left.svg';
export {default as close} from './close.svg';
export {default as critical} from './critical.svg';
export {default as discount} from './discount.svg';
export {default as delivery} from './delivery.svg';
export {default as delivered} from './delivered.svg';
export {default as disabled} from './disabled.svg';
export {default as errorFill} from './error-fill.svg';
export {default as info} from './info.svg';
export {default as lock} from './lock.svg';
export {default as questionFill} from './question-fill.svg';
export {default as ship} from './ship.svg';
export {default as success} from './success.svg';
export {default as warning} from './warning.svg';
export {default as warningCircle} from './warning-circle.svg';
export {default as warningFill} from './warning-fill.svg';
export {default as spinner} from './spinner.svg';
export {default as spinnerSmall} from './spinner-small.svg';
export {default as mobile} from './mobile.svg';

==> checkout-ui-react-0.5.0.tgz: package/src/icons/index.ts <==
export {default as arrowLeft} from './arrow-left.svg';
export {default as arrowRight} from './arrow-right.svg';
export {default as calendar} from './calendar.svg';
export {default as camera} from './camera.svg';
export {default as cancelCircle} from './cancel-circle.svg';
export {default as caretDown} from './caret-down.svg';
export {default as cart} from './cart.svg';
export {default as checkmark} from './checkmark.svg';
export {default as checkmarkCircle} from './checkmark-circle.svg';
export {default as chevronDown} from './chevron-down.svg';
export {default as chevronUp} from './chevron-up.svg';
export {default as chevronRight} from './chevron-right.svg';
export {default as chevronLeft} from './chevron-left.svg';
export {default as close} from './close.svg';
export {default as critical} from './critical.svg';
export {default as discount} from './discount.svg';
export {default as delivery} from './delivery.svg';
export {default as delivered} from './delivered.svg';
export {default as disabled} from './disabled.svg';
export {default as errorFill} from './error-fill.svg';
export {default as giftFill} from './gift-fill.svg';
export {default as geolocation} from './geolocation.svg';
export {default as info} from './info.svg';
export {default as list} from './list.svg';
export {default as locateMe} from './locate-me.svg';
export {default as lock} from './lock.svg';
export {default as mobile} from './mobile.svg';
export {default as map} from './map.svg';
export {default as marker} from './marker.svg';
export {default as questionFill} from './question-fill.svg';
export {default as reorder} from './re-order.svg';
export {default as store} from './store.svg';
export {default as success} from './success.svg';
export {default as truck} from './truck.svg';
export {default as warning} from './warning.svg';
export {default as warningCircle} from './warning-circle.svg';
export {default as warningFill} from './warning-fill.svg';
export {default as spinner} from './spinner.svg';
export {default as spinnerSmall} from './spinner-small.svg';
export {default as external} from './external.svg';
